==> dart_mssql-0.0.1.tar.gz: lib/src/sql_result.dart <==
import 'package:quiver/strings.dart';

String strSlice(String s, [int num=1]) {
  return isEmpty(s) ? "" : s.substring(0, s.length - 1);
}

class SqlResult {
  List columns;
  List rows;
  int rowsAffected = -1;
  int rowIndex = 0;
  String error;
  Map<String, dynamic> fieldIndexes = Map();

  SqlResult(this.columns, this.rows, this.rowsAffected) {
    rowIndex = 0;
    int i = 0;
    columns?.forEach((c) {
      fieldIndexes[c["name"]] = i;
      i++;
    });
  }

  SqlResult.fromMap(Map map) {
    this.rows = map["rows"];
    this.columns = map["columns"];
    this.rowsAffected = map["rowsAffected"];
    this.fieldIndexes = map["fieldIndexes"];
    this.error = map["error"];
  }

  int index(String fieldName) {
    return fieldIndexes[fieldName];
  }
  
  String values(String fieldName) {
    int fieldIndex = fieldIndexes[fieldName];
    String ids = "-1,";
    rows.forEach((e) {
      ids += e[fieldIndex].toString() + ",";
    });
    ids = strSlice(ids);
    return ids;
  }

  dynamic value(String fieldName) {
    return rows[rowIndex][fieldIndexes[fieldName]];
  }

  Map<String, dynamic> map() {
    Map<String, dynamic> result = Map();
    if (rowIndex < 0 || rowIndex >= rows.length) {
      columns.forEach((c) {
        result[c["name"]] = null;
      });
    } else {
      columns.forEach((c) {
        result[c["name"]] = rows[rowIndex][fieldIndexes[c["name"]]];
      });
    }
    return result;
  }

  bool next() {
    return (rows == null || rowIndex == rows.length) ? false : (){ rowIndex++;  return true; };
  }

  bool prior() {
    return (rows == null || rowIndex == 0) ? false : (){ rowIndex--;  return true; };
  }

  Map asMap() {
    return {
      "columns": columns,
      "rows": rows,
      "rowsAffected": rowsAffected,
      "fieldIndexes": fieldIndexes,
      "error": error,
    };
  }

  String mapToInsert(String tableName, Map<String, dynamic> map) {
    String fieldNames = "";
    String fieldValues = "";
    map.forEach((n, v) {
      fieldNames += n + ',';
      if (v is String) {
        fieldValues += "${v == null ? null : "'" + v.replaceAll("'","''") + "'"},";
      } else {
        fieldValues += "$v,";
      }
    });
    fieldNames = strSlice(fieldNames);
    fieldValues = strSlice(fieldValues);
    return "insert into $tableName($fieldNames) values ($fieldValues)";
  }

  String mapToUpdate(String tableName, Map<String, dynamic> map, String whereClause) {
    String fieldValues = "";
    map.forEach((n, v) {
      if (v is String) {
        fieldValues += "$n = ${v == null ? null : "'" + v.replaceAll("'","''") + "'"},";
      } else {
        fieldValues += "$n = $v,";
      }
    });
    fieldValues = strSlice(fieldValues);
    return "update $tableName set $fieldValues where $whereClause";
  }  
}

==> dart_mssql-0.0.4.tar.gz: lib/src/sql_result.dart <==
import 'package:quiver/strings.dart';

String strSlice(String s, [int num = 1]) {
  return isEmpty(s) ? "" : s.substring(0, s.length - 1);
}

class SqlResult {
  List columns;
  List rows;
  int rowsAffected = -1;
  int rowIndex = 0;
  String error;
  Map<String, dynamic> fieldIndexes = Map();

  SqlResult(this.columns, this.rows, this.rowsAffected) {
    rowIndex = 0;
    int i = 0;
    columns?.forEach((c) {
      fieldIndexes[c["name"]] = i;
      i++;
    });
  }

  SqlResult.fromMap(Map map) {
    this.rows = map["rows"];
    this.columns = map["columns"];
    this.rowsAffected = map["rowsAffected"];
    this.fieldIndexes = map["fieldIndexes"];
    this.error = map["error"];
  }

  int index(String fieldName) {
    return fieldIndexes[fieldName];
  }

  String values(String fieldName) {
    int fieldIndex = fieldIndexes[fieldName];
    String ids = "-1,";
    rows.forEach((e) {
      ids += e[fieldIndex].toString() + ",";
    });
    ids = strSlice(ids);
    return ids;
  }

  dynamic value(String fieldName) {
    return rows[rowIndex][fieldIndexes[fieldName]];
  }

  Map<String, dynamic> map() {
    Map<String, dynamic> result = Map();
    if (rowIndex < 0 || rowIndex >= rows.length) {
      columns.forEach((c) {
        result[c["name"]] = null;
      });
    } else {
      columns.forEach((c) {
        result[c["name"]] = rows[rowIndex][fieldIndexes[c["name"]]];
      });
    }
    return result;
  }

  bool next() {
    return (rows == null || rowIndex == rows.length)
        ? false
        : () {
            rowIndex++;
            return true;
          };
  }

  bool prior() {
    return (rows == null || rowIndex == 0)
        ? false
        : () {
            rowIndex--;
            return true;
          };
  }

  Map asMap() {
    return {
      "columns": columns,
      "rows": rows,
      "rowsAffected": rowsAffected,
      "fieldIndexes": fieldIndexes,
      "error": error,
    };
  }

  String mapToInsert(String tableName, Map<String, dynamic> map) {
    String fieldNames = "";
    String fieldValues = "";
    map.forEach((n, v) {
      fieldNames += n + ',';
      if (v is String) {
        fieldValues +=
            "${v == null ? null : "'" + v.replaceAll("'", "''") + "'"},";
      } else {
        fieldValues += "$v,";
      }
    });
    fieldNames = strSlice(fieldNames);
    fieldValues = strSlice(fieldValues);
    return "insert into $tableName($fieldNames) values ($fieldValues)";
  }

  String mapToUpdate(
      String tableName, Map<String, dynamic> map, String whereClause) {
    String fieldValues = "";
    map.forEach((n, v) {
      if (v is String) {
        fieldValues +=
            "$n = ${v == null ? null : "'" + v.replaceAll("'", "''") + "'"},";
      } else {
        fieldValues += "$n = $v,";
      }
    });
    fieldValues = strSlice(fieldValues);
    return "update $tableName set $fieldValues where $whereClause";
  }
}
